==> deepin-screen-recorder_5.8.1.orig.tar.xz: deepin-screen-recorder-5.8.1/translations/deepin-screen-recorder_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Napsauta valikon kuvaketta 
tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Kuvakaappaus</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ruudunkaappaus</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Tallennus epäonnistui. Tallenna se kotihakemistoon.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Kuva valmiina</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>valitse alue</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Tallenna nimellä %1</translation>
    </message>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ruudunkaappaus alkaa %1 sekunnissa</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ohita</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Leikepöydälle</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Näyttöä tallennetaan, odota...</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Kumoa</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ruudunkaappaus</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Tallennus valmis</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Tallenna nimellä %1</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ruudunkaappaus alkaa %1 sekunnissa</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Kirjoita teksti tähän</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Aloita/Kuvakaappaus</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Poistu/Tallenna</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Piirtäminen</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Säädä koko</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Pikakäynnistys</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Ikkunan kuvakaappaus</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Kuvakaappaus viiveellä</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Kokoruudun kaappaus</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopioi leikepöydälle</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Suorakulmio</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Soikio</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Viiva</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kynä</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Kumoa</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Lisää korkeutta ylöspäin</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Lisää mittaa alaspäin</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Lisää leveyttä vasemmalle</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Lisää leveyttä oikealle</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Pienennä korkeutta</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Pienennä mittaa alaosassa</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Pienennä leveyttä vasemmalla</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Pienennä leveyttä oikealla</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä kuvakkeet</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Hämärtää</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Ruudukkoa</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Ääni päällä</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofoni</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Järjestelmän ääni</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Ääni pois</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Näytä näppäimistö</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Piilota näppäimistö</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Kamera päällä</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Kamera pois</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Näytä napsautus</translation>
    </message>
    <message>
        <source>Hide Click</source>
        <translation>Piilota napsautus</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Muoto:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Suorakulmio</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Soikio</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Viiva</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Nuoli</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kynä</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Tallenna nimellä</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Kansio</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Muoto</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Leikepöydälle</translation>
    </message>
    <message>
        <source>Edit in Draw</source>
        <translation>Muokkaa ohjelmassa Piirtäminen</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Näytä osoitin</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Äänitykset</translation>
    </message>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Näytön tallennusta ei tueta tällä hetkellä</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.9.3.orig.tar.xz: deepin-screen-recorder-5.9.3/translations/deepin-screen-recorder_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Napsauta valikon kuvaketta 
tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Kuvakaappaus</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ruudunkaappaus</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Tallennus epäonnistui. Tallenna se kotihakemistoon.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Kuva valmiina</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>valitse alue</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Tallenna nimellä %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ohita</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Leikepöydälle</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Näyttöä tallennetaan, odota...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Koska ikkunatehosteet on poistettu käytöstä prosessin aikana, tallennus on pysäytetty</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Kuvakaappaus</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Kumoa</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Tallennus valmis</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Tallenna nimellä %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Tallenna</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ruudunkaappaus alkaa %1 sekunnissa</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Kirjoita teksti tähän</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Aloita/Kuvakaappaus</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Poistu/Tallenna</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Piirtäminen</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Säädä koko</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Pikakäynnistys</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Ikkunan kuvakaappaus</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Kuvakaappaus viiveellä</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Kokoruudun kaappaus</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Suorakulmio</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Soikio</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Viiva</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kynä</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Kumoa</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Lisää korkeutta ylöspäin</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Lisää mittaa alaspäin</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Lisää leveyttä vasemmalle</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Lisää leveyttä oikealle</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Pienennä korkeutta</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Pienennä mittaa alaosassa</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Pienennä leveyttä vasemmalla</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Pienennä leveyttä oikealla</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä kuvakkeet</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ääni</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Näppäimistö</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Aloita tallennus</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Aloita tallennus</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Hiiri</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Hämärtää</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Ruudukkoa</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Ääni päällä</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofoni</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Järjestelmän ääni</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Ääni pois</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Näytä näppäimistö</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Piilota näppäimistö</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Kamera päällä</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Kamera pois</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Näytä napsautus</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Muoto:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Suorakulmio</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Soikio</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Viiva</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Nuoli</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kynä</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Tallenna nimellä</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Kansio</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Muoto</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Leikepöydälle</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Näytä osoitin</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Hiiri</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Näytä osoitin</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Säädä tallennuksen aluetta %1*%2 saadaksesi paremman videotehosteen</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Äänitykset</translation>
    </message>
</context>
</TS>
